=============
API Reference
=============

.. currentmodule:: autofit

-------------------
Non-Linear Searches
-------------------

**Nested Samplers:**

.. autosummary::
   :toctree: generated/

   DynestyDynamic
   DynestyStatic
   MultiNest

**MCMC:**

.. autosummary::
   :toctree: generated/

   Emcee

**Optimizers:**

.. autosummary::
   :toctree: generated/

   PySwarmsGlobal

*`GridSearch`*:

.. autosummary::
   :toctree: generated/

   NonLinearSearchGridSearch
   GridSearchResult


------
Priors
------

.. autosummary::
   :toctree: generated/

   UniformPrior
   GaussianPrior
   LogUniformPrior

------
Models
------

.. autosummary::
   :toctree: generated/

   PriorModel
   CollectionPriorModel

-----
Paths
-----

.. autosummary::
   :toctree: generated/

   Paths

-------
Samples
-------

.. autosummary::
   :toctree: generated/

   OptimizerSamples
   PDFSamples
   MCMCSamples
   NestSamples

----------
Aggregator
----------

.. autosummary::
   :toctree: generated/

   Aggregator

-------
Backend
-------

.. autosummary::
   :toctree: generated/

   ModelMapper
   ModelInstance
